@@ -122,6 +122,8 @@ ResolverTempType = T.TypeVar("ResolverTempType", bound="Resolver")
 class Node(BaseModel):
     _cache: CacheManager = PrivateAttr(default_factory=CacheManager)
     _used_resolver: ResolverType = PrivateAttr(None)
+    _original_dict: dict = PrivateAttr(None)
+    _deleted: bool = PrivateAttr(None)
 
     id: str
 
@@ -242,6 +244,9 @@ class Node(BaseModel):
         # TODO
         pass
 
+    class Config:
+        validate_assignment = True
+
 
 from .resolver import Resolver
 
