@@ -77,6 +77,24 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         """
         return s
 
+    def make_update_mutation_str(self) -> str:
+        typename = self.node.Dgraph.typename
+        s = f"""
+            mutation Update{typename}($set: {typename}Patch, $remove: {typename}Patch, $filter: {typename}Filter!) {{
+                update{typename}(input: {{filter: $filter, set: $set, remove: $remove}}) {self.make_add_query_str()}
+            }}
+        """
+        return s
+
+    def make_delete_mutation_str(self) -> str:
+        typename = self.node.Dgraph.typename
+        s = f"""
+            mutation Delete{typename}($filter: {typename}Filter!) {{
+                delete{typename}(filter: $filter) {self.make_add_query_str()}
+            }}
+        """
+        return s
+
     async def query(self) -> T.List[NodeType]:
         s = self.make_query_query_str()
         lst: T.List[dict] = (await execute.gql(query_str=s))["data"][
@@ -102,6 +120,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                 value_to_save = val
             node.cache.add(key=field, resolver=resolver, val=value_to_save, gql_d=gql_d)
         node._used_resolver = self
+        node._original_dict = node.dict()
         return node
 
     async def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
